# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: activity_model.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='activity_model.proto',
  package='com.elarian.hera.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14\x61\x63tivity_model.proto\x12\x16\x63om.elarian.hera.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"a\n\x15\x41\x63tivityChannelNumber\x12\x38\n\x07\x63hannel\x18\x01 \x01(\x0e\x32\'.com.elarian.hera.proto.ActivityChannel\x12\x0e\n\x06number\x18\x02 \x01(\t\"\xd0\x01\n\x10\x43ustomerActivity\x12\x0b\n\x03key\x18\x01 \x01(\t\x12L\n\nproperties\x18\x02 \x03(\x0b\x32\x38.com.elarian.hera.proto.CustomerActivity.PropertiesEntry\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*j\n\x0f\x41\x63tivityChannel\x12 \n\x1c\x41\x43TIVITY_CHANNEL_UNSPECIFIED\x10\x00\x12\x18\n\x14\x41\x43TIVITY_CHANNEL_WEB\x10\x01\x12\x1b\n\x17\x41\x43TIVITY_CHANNEL_MOBILE\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_ACTIVITYCHANNEL = _descriptor.EnumDescriptor(
  name='ActivityChannel',
  full_name='com.elarian.hera.proto.ActivityChannel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTIVITY_CHANNEL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVITY_CHANNEL_WEB', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVITY_CHANNEL_MOBILE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=391,
  serialized_end=497,
)
_sym_db.RegisterEnumDescriptor(_ACTIVITYCHANNEL)

ActivityChannel = enum_type_wrapper.EnumTypeWrapper(_ACTIVITYCHANNEL)
ACTIVITY_CHANNEL_UNSPECIFIED = 0
ACTIVITY_CHANNEL_WEB = 1
ACTIVITY_CHANNEL_MOBILE = 2



_ACTIVITYCHANNELNUMBER = _descriptor.Descriptor(
  name='ActivityChannelNumber',
  full_name='com.elarian.hera.proto.ActivityChannelNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='com.elarian.hera.proto.ActivityChannelNumber.channel', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='com.elarian.hera.proto.ActivityChannelNumber.number', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=178,
)


_CUSTOMERACTIVITY_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='com.elarian.hera.proto.CustomerActivity.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.elarian.hera.proto.CustomerActivity.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.CustomerActivity.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=389,
)

_CUSTOMERACTIVITY = _descriptor.Descriptor(
  name='CustomerActivity',
  full_name='com.elarian.hera.proto.CustomerActivity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.elarian.hera.proto.CustomerActivity.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='com.elarian.hera.proto.CustomerActivity.properties', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='com.elarian.hera.proto.CustomerActivity.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CUSTOMERACTIVITY_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=389,
)

_ACTIVITYCHANNELNUMBER.fields_by_name['channel'].enum_type = _ACTIVITYCHANNEL
_CUSTOMERACTIVITY_PROPERTIESENTRY.containing_type = _CUSTOMERACTIVITY
_CUSTOMERACTIVITY.fields_by_name['properties'].message_type = _CUSTOMERACTIVITY_PROPERTIESENTRY
_CUSTOMERACTIVITY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ActivityChannelNumber'] = _ACTIVITYCHANNELNUMBER
DESCRIPTOR.message_types_by_name['CustomerActivity'] = _CUSTOMERACTIVITY
DESCRIPTOR.enum_types_by_name['ActivityChannel'] = _ACTIVITYCHANNEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ActivityChannelNumber = _reflection.GeneratedProtocolMessageType('ActivityChannelNumber', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYCHANNELNUMBER,
  '__module__' : 'activity_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ActivityChannelNumber)
  })
_sym_db.RegisterMessage(ActivityChannelNumber)

CustomerActivity = _reflection.GeneratedProtocolMessageType('CustomerActivity', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMERACTIVITY_PROPERTIESENTRY,
    '__module__' : 'activity_model_pb2'
    # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CustomerActivity.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _CUSTOMERACTIVITY,
  '__module__' : 'activity_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CustomerActivity)
  })
_sym_db.RegisterMessage(CustomerActivity)
_sym_db.RegisterMessage(CustomerActivity.PropertiesEntry)


_CUSTOMERACTIVITY_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)



"""
RSocket
~~~~~~~~~~~~~~

A RSocket implementation in Python.
"""
from rsocket.rsocket import RequestHandler, BaseRequestHandler
from rsocket.rsocket import RSocket
from rsocket.handlers import RequestResponseRequester, StreamHandler
from rsocket.payload import Payload
from reactivestreams import Publisher, Subscriber, Subscription



import pathlib
from setuptools import setup, find_packages

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setup(
    name="elarian",
    version="0.0.3",
    description="Official Elarian Python SDK",
    long_description=README,
    long_description_content_type="text/markdown",
    keywords="elarian africastalking sms ussd voice customer payments",
    url="https://github.com/ElarianLtd/python-sdk",
    author="Elarian",
    author_email="salama@elarian.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.9",
    ],
    package_dir={
        '': 'src',
        'rsocket': 'lib/rsocket/rsocket',
        'reactivestreams': 'lib/rsocket/reactivestreams'
    },
    packages=[
        'elarian',
        'rsocket',
        'elarian.utils',
        'elarian.models',
        'reactivestreams',
        'elarian.utils.generated',
    ],
    include_package_data=True,
    install_requires=[
        'protobuf==3.15.6',
    ],
    python_requires=">=3.7",
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: simulator_socket.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import common_model_pb2 as common__model__pb2
from . import messaging_model_pb2 as messaging__model__pb2
from . import payment_model_pb2 as payment__model__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='simulator_socket.proto',
  package='com.elarian.hera.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16simulator_socket.proto\x12\x16\x63om.elarian.hera.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x12\x63ommon_model.proto\x1a\x15messaging_model.proto\x1a\x13payment_model.proto\"\xa7\x02\n\x18SimulatorToServerCommand\x12Q\n\x0freceive_message\x18\x01 \x01(\x0b\x32\x36.com.elarian.hera.proto.ReceiveMessageSimulatorCommandH\x00\x12Q\n\x0freceive_payment\x18\x02 \x01(\x0b\x32\x36.com.elarian.hera.proto.ReceivePaymentSimulatorCommandH\x00\x12\\\n\x15update_payment_status\x18\x03 \x01(\x0b\x32;.com.elarian.hera.proto.UpdatePaymentStatusSimulatorCommandH\x00\x42\x07\n\x05\x65ntry\"\xee\x01\n\x1eReceiveMessageSimulatorCommand\x12\x17\n\x0f\x63ustomer_number\x18\x01 \x01(\t\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x39\n\x05parts\x18\x03 \x03(\x0b\x32*.com.elarian.hera.proto.InboundMessageBody\x12\x30\n\nsession_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xfb\x01\n\x1eReceivePaymentSimulatorCommand\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12\x44\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32,.com.elarian.hera.proto.PaymentChannelNumber\x12\x17\n\x0f\x63ustomer_number\x18\x03 \x01(\t\x12+\n\x05value\x18\x04 \x01(\x0b\x32\x1c.com.elarian.hera.proto.Cash\x12\x35\n\x06status\x18\x05 \x01(\x0e\x32%.com.elarian.hera.proto.PaymentStatus\"t\n#UpdatePaymentStatusSimulatorCommand\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12\x35\n\x06status\x18\x02 \x01(\x0e\x32%.com.elarian.hera.proto.PaymentStatus\"~\n\x1dSimulatorToServerCommandReply\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x38\n\x07message\x18\x03 \x01(\x0b\x32\'.com.elarian.hera.proto.OutboundMessage\"\xef\x03\n\x1dServerToSimulatorNotification\x12P\n\x0csend_message\x18\x01 \x01(\x0b\x32\x38.com.elarian.hera.proto.SendMessageSimulatorNotificationH\x00\x12U\n\x0fmake_voice_call\x18\x02 \x01(\x0b\x32:.com.elarian.hera.proto.MakeVoiceCallSimulatorNotificationH\x00\x12\x61\n\x15send_customer_payment\x18\x03 \x01(\x0b\x32@.com.elarian.hera.proto.SendCustomerPaymentSimulatorNotificationH\x00\x12_\n\x14send_channel_payment\x18\x04 \x01(\x0b\x32?.com.elarian.hera.proto.SendChannelPaymentSimulatorNotificationH\x00\x12X\n\x10\x63heckout_payment\x18\x05 \x01(\x0b\x32<.com.elarian.hera.proto.CheckoutPaymentSimulatorNotificationH\x00\x42\x07\n\x05\x65ntry\"$\n\"ServerToSimulatorNotificationReply\"\x9e\x02\n SendMessageSimulatorNotification\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x13\n\x0b\x63ustomer_id\x18\x02 \x01(\t\x12\x12\n\nmessage_id\x18\x03 \x01(\t\x12?\n\x0f\x63ustomer_number\x18\x04 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x05 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x38\n\x07message\x18\x06 \x01(\x0b\x32\'.com.elarian.hera.proto.OutboundMessage\"\xe6\x01\n\"MakeVoiceCallSimulatorNotification\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x13\n\x0b\x63ustomer_id\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12?\n\x0f\x63ustomer_number\x18\x04 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x05 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\"\xc2\x03\n(SendCustomerPaymentSimulatorNotification\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x13\n\x0b\x63ustomer_id\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\t\x12\x43\n\x06wallet\x18\x04 \x01(\x0b\x32\x31.com.elarian.hera.proto.PaymentWalletCounterPartyH\x00\x12\x41\n\x05purse\x18\x05 \x01(\x0b\x32\x30.com.elarian.hera.proto.PaymentPurseCounterPartyH\x00\x12\x16\n\x0etransaction_id\x18\x06 \x01(\t\x12?\n\x0f\x63ustomer_number\x18\x07 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x44\n\x0e\x63hannel_number\x18\x08 \x01(\x0b\x32,.com.elarian.hera.proto.PaymentChannelNumber\x12+\n\x05value\x18\t \x01(\x0b\x32\x1c.com.elarian.hera.proto.CashB\r\n\x0b\x64\x65\x62it_party\"\x9a\x03\n\'SendChannelPaymentSimulatorNotification\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\t\x12\x43\n\x06wallet\x18\x03 \x01(\x0b\x32\x31.com.elarian.hera.proto.PaymentWalletCounterPartyH\x00\x12\x41\n\x05purse\x18\x04 \x01(\x0b\x32\x30.com.elarian.hera.proto.PaymentPurseCounterPartyH\x00\x12\x16\n\x0etransaction_id\x18\x05 \x01(\t\x12\x44\n\x0e\x63hannel_number\x18\x06 \x01(\x0b\x32,.com.elarian.hera.proto.PaymentChannelNumber\x12-\n\x07\x61\x63\x63ount\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05value\x18\x08 \x01(\x0b\x32\x1c.com.elarian.hera.proto.CashB\r\n\x0b\x64\x65\x62it_party\"\xbf\x03\n$CheckoutPaymentSimulatorNotification\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x13\n\x0b\x63ustomer_id\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\t\x12\x43\n\x06wallet\x18\x04 \x01(\x0b\x32\x31.com.elarian.hera.proto.PaymentWalletCounterPartyH\x00\x12\x41\n\x05purse\x18\x05 \x01(\x0b\x32\x30.com.elarian.hera.proto.PaymentPurseCounterPartyH\x00\x12\x16\n\x0etransaction_id\x18\x06 \x01(\t\x12?\n\x0f\x63ustomer_number\x18\x07 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x44\n\x0e\x63hannel_number\x18\x08 \x01(\x0b\x32,.com.elarian.hera.proto.PaymentChannelNumber\x12+\n\x05value\x18\t \x01(\x0b\x32\x1c.com.elarian.hera.proto.CashB\x0e\n\x0c\x63redit_partyb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,common__model__pb2.DESCRIPTOR,messaging__model__pb2.DESCRIPTOR,payment__model__pb2.DESCRIPTOR,])




_SIMULATORTOSERVERCOMMAND = _descriptor.Descriptor(
  name='SimulatorToServerCommand',
  full_name='com.elarian.hera.proto.SimulatorToServerCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='receive_message', full_name='com.elarian.hera.proto.SimulatorToServerCommand.receive_message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receive_payment', full_name='com.elarian.hera.proto.SimulatorToServerCommand.receive_payment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_payment_status', full_name='com.elarian.hera.proto.SimulatorToServerCommand.update_payment_status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.SimulatorToServerCommand.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=147,
  serialized_end=442,
)


_RECEIVEMESSAGESIMULATORCOMMAND = _descriptor.Descriptor(
  name='ReceiveMessageSimulatorCommand',
  full_name='com.elarian.hera.proto.ReceiveMessageSimulatorCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.ReceiveMessageSimulatorCommand.customer_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.ReceiveMessageSimulatorCommand.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parts', full_name='com.elarian.hera.proto.ReceiveMessageSimulatorCommand.parts', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.ReceiveMessageSimulatorCommand.session_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=683,
)


_RECEIVEPAYMENTSIMULATORCOMMAND = _descriptor.Descriptor(
  name='ReceivePaymentSimulatorCommand',
  full_name='com.elarian.hera.proto.ReceivePaymentSimulatorCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.ReceivePaymentSimulatorCommand.transaction_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.ReceivePaymentSimulatorCommand.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.ReceivePaymentSimulatorCommand.customer_number', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.ReceivePaymentSimulatorCommand.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.ReceivePaymentSimulatorCommand.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=686,
  serialized_end=937,
)


_UPDATEPAYMENTSTATUSSIMULATORCOMMAND = _descriptor.Descriptor(
  name='UpdatePaymentStatusSimulatorCommand',
  full_name='com.elarian.hera.proto.UpdatePaymentStatusSimulatorCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.UpdatePaymentStatusSimulatorCommand.transaction_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.UpdatePaymentStatusSimulatorCommand.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=1055,
)


_SIMULATORTOSERVERCOMMANDREPLY = _descriptor.Descriptor(
  name='SimulatorToServerCommandReply',
  full_name='com.elarian.hera.proto.SimulatorToServerCommandReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.SimulatorToServerCommandReply.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.elarian.hera.proto.SimulatorToServerCommandReply.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.elarian.hera.proto.SimulatorToServerCommandReply.message', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1057,
  serialized_end=1183,
)


_SERVERTOSIMULATORNOTIFICATION = _descriptor.Descriptor(
  name='ServerToSimulatorNotification',
  full_name='com.elarian.hera.proto.ServerToSimulatorNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='send_message', full_name='com.elarian.hera.proto.ServerToSimulatorNotification.send_message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='make_voice_call', full_name='com.elarian.hera.proto.ServerToSimulatorNotification.make_voice_call', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_customer_payment', full_name='com.elarian.hera.proto.ServerToSimulatorNotification.send_customer_payment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_channel_payment', full_name='com.elarian.hera.proto.ServerToSimulatorNotification.send_channel_payment', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkout_payment', full_name='com.elarian.hera.proto.ServerToSimulatorNotification.checkout_payment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.ServerToSimulatorNotification.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1186,
  serialized_end=1681,
)


_SERVERTOSIMULATORNOTIFICATIONREPLY = _descriptor.Descriptor(
  name='ServerToSimulatorNotificationReply',
  full_name='com.elarian.hera.proto.ServerToSimulatorNotificationReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1683,
  serialized_end=1719,
)


_SENDMESSAGESIMULATORNOTIFICATION = _descriptor.Descriptor(
  name='SendMessageSimulatorNotification',
  full_name='com.elarian.hera.proto.SendMessageSimulatorNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='com.elarian.hera.proto.SendMessageSimulatorNotification.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.SendMessageSimulatorNotification.customer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='com.elarian.hera.proto.SendMessageSimulatorNotification.message_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.SendMessageSimulatorNotification.customer_number', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.SendMessageSimulatorNotification.channel_number', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.elarian.hera.proto.SendMessageSimulatorNotification.message', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1722,
  serialized_end=2008,
)


_MAKEVOICECALLSIMULATORNOTIFICATION = _descriptor.Descriptor(
  name='MakeVoiceCallSimulatorNotification',
  full_name='com.elarian.hera.proto.MakeVoiceCallSimulatorNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='com.elarian.hera.proto.MakeVoiceCallSimulatorNotification.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.MakeVoiceCallSimulatorNotification.customer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.MakeVoiceCallSimulatorNotification.session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.MakeVoiceCallSimulatorNotification.customer_number', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.MakeVoiceCallSimulatorNotification.channel_number', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2011,
  serialized_end=2241,
)


_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION = _descriptor.Descriptor(
  name='SendCustomerPaymentSimulatorNotification',
  full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.customer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.app_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.wallet', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purse', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.purse', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.transaction_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.customer_number', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.channel_number', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.value', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='debit_party', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.debit_party',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2244,
  serialized_end=2694,
)


_SENDCHANNELPAYMENTSIMULATORNOTIFICATION = _descriptor.Descriptor(
  name='SendChannelPaymentSimulatorNotification',
  full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.app_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.wallet', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purse', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.purse', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.transaction_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.channel_number', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.account', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.value', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='debit_party', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.debit_party',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2697,
  serialized_end=3107,
)


_CHECKOUTPAYMENTSIMULATORNOTIFICATION = _descriptor.Descriptor(
  name='CheckoutPaymentSimulatorNotification',
  full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.customer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.app_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.wallet', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purse', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.purse', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.transaction_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.customer_number', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.channel_number', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.value', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='credit_party', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.credit_party',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3110,
  serialized_end=3557,
)

_SIMULATORTOSERVERCOMMAND.fields_by_name['receive_message'].message_type = _RECEIVEMESSAGESIMULATORCOMMAND
_SIMULATORTOSERVERCOMMAND.fields_by_name['receive_payment'].message_type = _RECEIVEPAYMENTSIMULATORCOMMAND
_SIMULATORTOSERVERCOMMAND.fields_by_name['update_payment_status'].message_type = _UPDATEPAYMENTSTATUSSIMULATORCOMMAND
_SIMULATORTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _SIMULATORTOSERVERCOMMAND.fields_by_name['receive_message'])
_SIMULATORTOSERVERCOMMAND.fields_by_name['receive_message'].containing_oneof = _SIMULATORTOSERVERCOMMAND.oneofs_by_name['entry']
_SIMULATORTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _SIMULATORTOSERVERCOMMAND.fields_by_name['receive_payment'])
_SIMULATORTOSERVERCOMMAND.fields_by_name['receive_payment'].containing_oneof = _SIMULATORTOSERVERCOMMAND.oneofs_by_name['entry']
_SIMULATORTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _SIMULATORTOSERVERCOMMAND.fields_by_name['update_payment_status'])
_SIMULATORTOSERVERCOMMAND.fields_by_name['update_payment_status'].containing_oneof = _SIMULATORTOSERVERCOMMAND.oneofs_by_name['entry']
_RECEIVEMESSAGESIMULATORCOMMAND.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_RECEIVEMESSAGESIMULATORCOMMAND.fields_by_name['parts'].message_type = messaging__model__pb2._INBOUNDMESSAGEBODY
_RECEIVEMESSAGESIMULATORCOMMAND.fields_by_name['session_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECEIVEPAYMENTSIMULATORCOMMAND.fields_by_name['channel_number'].message_type = payment__model__pb2._PAYMENTCHANNELNUMBER
_RECEIVEPAYMENTSIMULATORCOMMAND.fields_by_name['value'].message_type = common__model__pb2._CASH
_RECEIVEPAYMENTSIMULATORCOMMAND.fields_by_name['status'].enum_type = payment__model__pb2._PAYMENTSTATUS
_UPDATEPAYMENTSTATUSSIMULATORCOMMAND.fields_by_name['status'].enum_type = payment__model__pb2._PAYMENTSTATUS
_SIMULATORTOSERVERCOMMANDREPLY.fields_by_name['message'].message_type = messaging__model__pb2._OUTBOUNDMESSAGE
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_message'].message_type = _SENDMESSAGESIMULATORNOTIFICATION
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['make_voice_call'].message_type = _MAKEVOICECALLSIMULATORNOTIFICATION
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_customer_payment'].message_type = _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_channel_payment'].message_type = _SENDCHANNELPAYMENTSIMULATORNOTIFICATION
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['checkout_payment'].message_type = _CHECKOUTPAYMENTSIMULATORNOTIFICATION
_SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_message'])
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_message'].containing_oneof = _SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry']
_SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOSIMULATORNOTIFICATION.fields_by_name['make_voice_call'])
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['make_voice_call'].containing_oneof = _SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry']
_SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_customer_payment'])
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_customer_payment'].containing_oneof = _SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry']
_SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_channel_payment'])
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_channel_payment'].containing_oneof = _SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry']
_SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOSIMULATORNOTIFICATION.fields_by_name['checkout_payment'])
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['checkout_payment'].containing_oneof = _SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry']
_SENDMESSAGESIMULATORNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_SENDMESSAGESIMULATORNOTIFICATION.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_SENDMESSAGESIMULATORNOTIFICATION.fields_by_name['message'].message_type = messaging__model__pb2._OUTBOUNDMESSAGE
_MAKEVOICECALLSIMULATORNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_MAKEVOICECALLSIMULATORNOTIFICATION.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'].message_type = payment__model__pb2._PAYMENTWALLETCOUNTERPARTY
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'].message_type = payment__model__pb2._PAYMENTPURSECOUNTERPARTY
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['channel_number'].message_type = payment__model__pb2._PAYMENTCHANNELNUMBER
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['value'].message_type = common__model__pb2._CASH
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party'].fields.append(
  _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'])
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'].containing_oneof = _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party']
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party'].fields.append(
  _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'])
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'].containing_oneof = _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party']
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'].message_type = payment__model__pb2._PAYMENTWALLETCOUNTERPARTY
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'].message_type = payment__model__pb2._PAYMENTPURSECOUNTERPARTY
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['channel_number'].message_type = payment__model__pb2._PAYMENTCHANNELNUMBER
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['account'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['value'].message_type = common__model__pb2._CASH
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party'].fields.append(
  _SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'])
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'].containing_oneof = _SENDCHANNELPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party']
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party'].fields.append(
  _SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'])
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'].containing_oneof = _SENDCHANNELPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party']
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'].message_type = payment__model__pb2._PAYMENTWALLETCOUNTERPARTY
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'].message_type = payment__model__pb2._PAYMENTPURSECOUNTERPARTY
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['channel_number'].message_type = payment__model__pb2._PAYMENTCHANNELNUMBER
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['value'].message_type = common__model__pb2._CASH
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['credit_party'].fields.append(
  _CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'])
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'].containing_oneof = _CHECKOUTPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['credit_party']
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['credit_party'].fields.append(
  _CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'])
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'].containing_oneof = _CHECKOUTPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['credit_party']
DESCRIPTOR.message_types_by_name['SimulatorToServerCommand'] = _SIMULATORTOSERVERCOMMAND
DESCRIPTOR.message_types_by_name['ReceiveMessageSimulatorCommand'] = _RECEIVEMESSAGESIMULATORCOMMAND
DESCRIPTOR.message_types_by_name['ReceivePaymentSimulatorCommand'] = _RECEIVEPAYMENTSIMULATORCOMMAND
DESCRIPTOR.message_types_by_name['UpdatePaymentStatusSimulatorCommand'] = _UPDATEPAYMENTSTATUSSIMULATORCOMMAND
DESCRIPTOR.message_types_by_name['SimulatorToServerCommandReply'] = _SIMULATORTOSERVERCOMMANDREPLY
DESCRIPTOR.message_types_by_name['ServerToSimulatorNotification'] = _SERVERTOSIMULATORNOTIFICATION
DESCRIPTOR.message_types_by_name['ServerToSimulatorNotificationReply'] = _SERVERTOSIMULATORNOTIFICATIONREPLY
DESCRIPTOR.message_types_by_name['SendMessageSimulatorNotification'] = _SENDMESSAGESIMULATORNOTIFICATION
DESCRIPTOR.message_types_by_name['MakeVoiceCallSimulatorNotification'] = _MAKEVOICECALLSIMULATORNOTIFICATION
DESCRIPTOR.message_types_by_name['SendCustomerPaymentSimulatorNotification'] = _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION
DESCRIPTOR.message_types_by_name['SendChannelPaymentSimulatorNotification'] = _SENDCHANNELPAYMENTSIMULATORNOTIFICATION
DESCRIPTOR.message_types_by_name['CheckoutPaymentSimulatorNotification'] = _CHECKOUTPAYMENTSIMULATORNOTIFICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimulatorToServerCommand = _reflection.GeneratedProtocolMessageType('SimulatorToServerCommand', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATORTOSERVERCOMMAND,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SimulatorToServerCommand)
  })
_sym_db.RegisterMessage(SimulatorToServerCommand)

ReceiveMessageSimulatorCommand = _reflection.GeneratedProtocolMessageType('ReceiveMessageSimulatorCommand', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVEMESSAGESIMULATORCOMMAND,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ReceiveMessageSimulatorCommand)
  })
_sym_db.RegisterMessage(ReceiveMessageSimulatorCommand)

ReceivePaymentSimulatorCommand = _reflection.GeneratedProtocolMessageType('ReceivePaymentSimulatorCommand', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVEPAYMENTSIMULATORCOMMAND,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ReceivePaymentSimulatorCommand)
  })
_sym_db.RegisterMessage(ReceivePaymentSimulatorCommand)

UpdatePaymentStatusSimulatorCommand = _reflection.GeneratedProtocolMessageType('UpdatePaymentStatusSimulatorCommand', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPAYMENTSTATUSSIMULATORCOMMAND,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.UpdatePaymentStatusSimulatorCommand)
  })
_sym_db.RegisterMessage(UpdatePaymentStatusSimulatorCommand)

SimulatorToServerCommandReply = _reflection.GeneratedProtocolMessageType('SimulatorToServerCommandReply', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATORTOSERVERCOMMANDREPLY,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SimulatorToServerCommandReply)
  })
_sym_db.RegisterMessage(SimulatorToServerCommandReply)

ServerToSimulatorNotification = _reflection.GeneratedProtocolMessageType('ServerToSimulatorNotification', (_message.Message,), {
  'DESCRIPTOR' : _SERVERTOSIMULATORNOTIFICATION,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ServerToSimulatorNotification)
  })
_sym_db.RegisterMessage(ServerToSimulatorNotification)

ServerToSimulatorNotificationReply = _reflection.GeneratedProtocolMessageType('ServerToSimulatorNotificationReply', (_message.Message,), {
  'DESCRIPTOR' : _SERVERTOSIMULATORNOTIFICATIONREPLY,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ServerToSimulatorNotificationReply)
  })
_sym_db.RegisterMessage(ServerToSimulatorNotificationReply)

SendMessageSimulatorNotification = _reflection.GeneratedProtocolMessageType('SendMessageSimulatorNotification', (_message.Message,), {
  'DESCRIPTOR' : _SENDMESSAGESIMULATORNOTIFICATION,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SendMessageSimulatorNotification)
  })
_sym_db.RegisterMessage(SendMessageSimulatorNotification)

MakeVoiceCallSimulatorNotification = _reflection.GeneratedProtocolMessageType('MakeVoiceCallSimulatorNotification', (_message.Message,), {
  'DESCRIPTOR' : _MAKEVOICECALLSIMULATORNOTIFICATION,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MakeVoiceCallSimulatorNotification)
  })
_sym_db.RegisterMessage(MakeVoiceCallSimulatorNotification)

SendCustomerPaymentSimulatorNotification = _reflection.GeneratedProtocolMessageType('SendCustomerPaymentSimulatorNotification', (_message.Message,), {
  'DESCRIPTOR' : _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification)
  })
_sym_db.RegisterMessage(SendCustomerPaymentSimulatorNotification)

SendChannelPaymentSimulatorNotification = _reflection.GeneratedProtocolMessageType('SendChannelPaymentSimulatorNotification', (_message.Message,), {
  'DESCRIPTOR' : _SENDCHANNELPAYMENTSIMULATORNOTIFICATION,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SendChannelPaymentSimulatorNotification)
  })
_sym_db.RegisterMessage(SendChannelPaymentSimulatorNotification)

CheckoutPaymentSimulatorNotification = _reflection.GeneratedProtocolMessageType('CheckoutPaymentSimulatorNotification', (_message.Message,), {
  'DESCRIPTOR' : _CHECKOUTPAYMENTSIMULATORNOTIFICATION,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CheckoutPaymentSimulatorNotification)
  })
_sym_db.RegisterMessage(CheckoutPaymentSimulatorNotification)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messaging_state.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import common_model_pb2 as common__model__pb2
from . import messaging_model_pb2 as messaging__model__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='messaging_state.proto',
  package='com.elarian.hera.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15messaging_state.proto\x12\x16\x63om.elarian.hera.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x12\x63ommon_model.proto\x1a\x15messaging_model.proto\"\xe4\x02\n\x0fReceivedMessage\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\nsession_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bin_reply_to\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x08provider\x18\x05 \x01(\x0e\x32-.com.elarian.hera.proto.ChannelNumberProvider\x12,\n\x06\x61pp_id\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x05parts\x18\x07 \x03(\x0b\x32*.com.elarian.hera.proto.InboundMessageBody\"\x8f\x04\n\x0bSentMessage\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\nsession_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bin_reply_to\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x08provider\x18\x05 \x01(\x0e\x32-.com.elarian.hera.proto.ChannelNumberProvider\x12,\n\x06\x61pp_id\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x06status\x18\x08 \x01(\x0e\x32-.com.elarian.hera.proto.MessageDeliveryStatus\x12?\n\treactions\x18\t \x03(\x0b\x32,.com.elarian.hera.proto.MessageReactionState\x12\x38\n\x07message\x18\n \x01(\x0b\x32\'.com.elarian.hera.proto.OutboundMessage\"\x81\x01\n\x14MessageReactionState\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x08reaction\x18\x02 \x01(\x0e\x32\'.com.elarian.hera.proto.MessageReaction\"R\n\x11MessageReplyToken\x12\r\n\x05token\x18\x01 \x01(\t\x12.\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8b\x01\n\x0e\x43hannelMessage\x12;\n\x08received\x18\x01 \x01(\x0b\x32\'.com.elarian.hera.proto.ReceivedMessageH\x00\x12\x33\n\x04sent\x18\x02 \x01(\x0b\x32#.com.elarian.hera.proto.SentMessageH\x00\x42\x07\n\x05\x65ntry\"\xe3\x01\n\x18\x43ompleteMessagingSession\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0f\n\x07\x61pp_ids\x18\x04 \x03(\t\x12\x45\n\nend_reason\x18\x05 \x01(\x0e\x32\x31.com.elarian.hera.proto.MessagingSessionEndReason\"\x95\x03\n\x1c\x42lockedMessagingChannelState\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x38\n\x08messages\x18\x03 \x03(\x0b\x32&.com.elarian.hera.proto.ChannelMessage\x12>\n\x0breply_token\x18\x04 \x01(\x0b\x32).com.elarian.hera.proto.MessageReplyToken\x12\x42\n\x08sessions\x18\x05 \x03(\x0b\x32\x30.com.elarian.hera.proto.CompleteMessagingSession\x12.\n\nblocked_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x94\x03\n\x1b\x41\x63tiveMessagingChannelState\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x38\n\x08messages\x18\x03 \x03(\x0b\x32&.com.elarian.hera.proto.ChannelMessage\x12>\n\x0breply_token\x18\x04 \x01(\x0b\x32).com.elarian.hera.proto.MessageReplyToken\x12\x42\n\x08sessions\x18\x05 \x03(\x0b\x32\x30.com.elarian.hera.proto.CompleteMessagingSession\x12.\n\nallowed_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9c\x04\n\x1eInSessionMessagingChannelState\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x38\n\x08messages\x18\x03 \x03(\x0b\x32&.com.elarian.hera.proto.ChannelMessage\x12>\n\x0breply_token\x18\x04 \x01(\x0b\x32).com.elarian.hera.proto.MessageReplyToken\x12\x42\n\x08sessions\x18\x05 \x03(\x0b\x32\x30.com.elarian.hera.proto.CompleteMessagingSession\x12.\n\nallowed_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nsession_id\x18\x07 \x01(\t\x12.\n\nstarted_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61pp_ids\x18\n \x03(\t\"\xfe\x01\n\x15MessagingChannelState\x12G\n\x07\x62locked\x18\x01 \x01(\x0b\x32\x34.com.elarian.hera.proto.BlockedMessagingChannelStateH\x00\x12\x45\n\x06\x61\x63tive\x18\x02 \x01(\x0b\x32\x33.com.elarian.hera.proto.ActiveMessagingChannelStateH\x00\x12L\n\nin_session\x18\x03 \x01(\x0b\x32\x36.com.elarian.hera.proto.InSessionMessagingChannelStateH\x00\x42\x07\n\x05state\"Q\n\x0eMessagingState\x12?\n\x08\x63hannels\x18\x01 \x03(\x0b\x32-.com.elarian.hera.proto.MessagingChannelStateb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,common__model__pb2.DESCRIPTOR,messaging__model__pb2.DESCRIPTOR,])




_RECEIVEDMESSAGE = _descriptor.Descriptor(
  name='ReceivedMessage',
  full_name='com.elarian.hera.proto.ReceivedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='com.elarian.hera.proto.ReceivedMessage.message_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='com.elarian.hera.proto.ReceivedMessage.created_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.ReceivedMessage.session_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_reply_to', full_name='com.elarian.hera.proto.ReceivedMessage.in_reply_to', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='com.elarian.hera.proto.ReceivedMessage.provider', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.ReceivedMessage.app_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parts', full_name='com.elarian.hera.proto.ReceivedMessage.parts', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=546,
)


_SENTMESSAGE = _descriptor.Descriptor(
  name='SentMessage',
  full_name='com.elarian.hera.proto.SentMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='com.elarian.hera.proto.SentMessage.message_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='com.elarian.hera.proto.SentMessage.created_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.SentMessage.session_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_reply_to', full_name='com.elarian.hera.proto.SentMessage.in_reply_to', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='com.elarian.hera.proto.SentMessage.provider', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.SentMessage.app_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='com.elarian.hera.proto.SentMessage.updated_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.SentMessage.status', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reactions', full_name='com.elarian.hera.proto.SentMessage.reactions', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.elarian.hera.proto.SentMessage.message', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=549,
  serialized_end=1076,
)


_MESSAGEREACTIONSTATE = _descriptor.Descriptor(
  name='MessageReactionState',
  full_name='com.elarian.hera.proto.MessageReactionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='created_at', full_name='com.elarian.hera.proto.MessageReactionState.created_at', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction', full_name='com.elarian.hera.proto.MessageReactionState.reaction', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1079,
  serialized_end=1208,
)


_MESSAGEREPLYTOKEN = _descriptor.Descriptor(
  name='MessageReplyToken',
  full_name='com.elarian.hera.proto.MessageReplyToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='com.elarian.hera.proto.MessageReplyToken.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='com.elarian.hera.proto.MessageReplyToken.expires_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1210,
  serialized_end=1292,
)


_CHANNELMESSAGE = _descriptor.Descriptor(
  name='ChannelMessage',
  full_name='com.elarian.hera.proto.ChannelMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='received', full_name='com.elarian.hera.proto.ChannelMessage.received', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sent', full_name='com.elarian.hera.proto.ChannelMessage.sent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.ChannelMessage.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1295,
  serialized_end=1434,
)


_COMPLETEMESSAGINGSESSION = _descriptor.Descriptor(
  name='CompleteMessagingSession',
  full_name='com.elarian.hera.proto.CompleteMessagingSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.CompleteMessagingSession.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='com.elarian.hera.proto.CompleteMessagingSession.started_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='com.elarian.hera.proto.CompleteMessagingSession.duration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_ids', full_name='com.elarian.hera.proto.CompleteMessagingSession.app_ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_reason', full_name='com.elarian.hera.proto.CompleteMessagingSession.end_reason', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1437,
  serialized_end=1664,
)


_BLOCKEDMESSAGINGCHANNELSTATE = _descriptor.Descriptor(
  name='BlockedMessagingChannelState',
  full_name='com.elarian.hera.proto.BlockedMessagingChannelState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.BlockedMessagingChannelState.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.BlockedMessagingChannelState.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='com.elarian.hera.proto.BlockedMessagingChannelState.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_token', full_name='com.elarian.hera.proto.BlockedMessagingChannelState.reply_token', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessions', full_name='com.elarian.hera.proto.BlockedMessagingChannelState.sessions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blocked_at', full_name='com.elarian.hera.proto.BlockedMessagingChannelState.blocked_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1667,
  serialized_end=2072,
)


_ACTIVEMESSAGINGCHANNELSTATE = _descriptor.Descriptor(
  name='ActiveMessagingChannelState',
  full_name='com.elarian.hera.proto.ActiveMessagingChannelState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.ActiveMessagingChannelState.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.ActiveMessagingChannelState.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='com.elarian.hera.proto.ActiveMessagingChannelState.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_token', full_name='com.elarian.hera.proto.ActiveMessagingChannelState.reply_token', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessions', full_name='com.elarian.hera.proto.ActiveMessagingChannelState.sessions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_at', full_name='com.elarian.hera.proto.ActiveMessagingChannelState.allowed_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2075,
  serialized_end=2479,
)


_INSESSIONMESSAGINGCHANNELSTATE = _descriptor.Descriptor(
  name='InSessionMessagingChannelState',
  full_name='com.elarian.hera.proto.InSessionMessagingChannelState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_token', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.reply_token', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessions', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.sessions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_at', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.allowed_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.session_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.started_at', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.expires_at', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_ids', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.app_ids', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2482,
  serialized_end=3022,
)


_MESSAGINGCHANNELSTATE = _descriptor.Descriptor(
  name='MessagingChannelState',
  full_name='com.elarian.hera.proto.MessagingChannelState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocked', full_name='com.elarian.hera.proto.MessagingChannelState.blocked', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='com.elarian.hera.proto.MessagingChannelState.active', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_session', full_name='com.elarian.hera.proto.MessagingChannelState.in_session', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='state', full_name='com.elarian.hera.proto.MessagingChannelState.state',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3025,
  serialized_end=3279,
)


_MESSAGINGSTATE = _descriptor.Descriptor(
  name='MessagingState',
  full_name='com.elarian.hera.proto.MessagingState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channels', full_name='com.elarian.hera.proto.MessagingState.channels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3281,
  serialized_end=3362,
)

_RECEIVEDMESSAGE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RECEIVEDMESSAGE.fields_by_name['session_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECEIVEDMESSAGE.fields_by_name['in_reply_to'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECEIVEDMESSAGE.fields_by_name['provider'].enum_type = common__model__pb2._CHANNELNUMBERPROVIDER
_RECEIVEDMESSAGE.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECEIVEDMESSAGE.fields_by_name['parts'].message_type = messaging__model__pb2._INBOUNDMESSAGEBODY
_SENTMESSAGE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SENTMESSAGE.fields_by_name['session_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SENTMESSAGE.fields_by_name['in_reply_to'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SENTMESSAGE.fields_by_name['provider'].enum_type = common__model__pb2._CHANNELNUMBERPROVIDER
_SENTMESSAGE.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SENTMESSAGE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SENTMESSAGE.fields_by_name['status'].enum_type = messaging__model__pb2._MESSAGEDELIVERYSTATUS
_SENTMESSAGE.fields_by_name['reactions'].message_type = _MESSAGEREACTIONSTATE
_SENTMESSAGE.fields_by_name['message'].message_type = messaging__model__pb2._OUTBOUNDMESSAGE
_MESSAGEREACTIONSTATE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MESSAGEREACTIONSTATE.fields_by_name['reaction'].enum_type = messaging__model__pb2._MESSAGEREACTION
_MESSAGEREPLYTOKEN.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CHANNELMESSAGE.fields_by_name['received'].message_type = _RECEIVEDMESSAGE
_CHANNELMESSAGE.fields_by_name['sent'].message_type = _SENTMESSAGE
_CHANNELMESSAGE.oneofs_by_name['entry'].fields.append(
  _CHANNELMESSAGE.fields_by_name['received'])
_CHANNELMESSAGE.fields_by_name['received'].containing_oneof = _CHANNELMESSAGE.oneofs_by_name['entry']
_CHANNELMESSAGE.oneofs_by_name['entry'].fields.append(
  _CHANNELMESSAGE.fields_by_name['sent'])
_CHANNELMESSAGE.fields_by_name['sent'].containing_oneof = _CHANNELMESSAGE.oneofs_by_name['entry']
_COMPLETEMESSAGINGSESSION.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMPLETEMESSAGINGSESSION.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_COMPLETEMESSAGINGSESSION.fields_by_name['end_reason'].enum_type = messaging__model__pb2._MESSAGINGSESSIONENDREASON
_BLOCKEDMESSAGINGCHANNELSTATE.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_BLOCKEDMESSAGINGCHANNELSTATE.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_BLOCKEDMESSAGINGCHANNELSTATE.fields_by_name['messages'].message_type = _CHANNELMESSAGE
_BLOCKEDMESSAGINGCHANNELSTATE.fields_by_name['reply_token'].message_type = _MESSAGEREPLYTOKEN
_BLOCKEDMESSAGINGCHANNELSTATE.fields_by_name['sessions'].message_type = _COMPLETEMESSAGINGSESSION
_BLOCKEDMESSAGINGCHANNELSTATE.fields_by_name['blocked_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVEMESSAGINGCHANNELSTATE.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_ACTIVEMESSAGINGCHANNELSTATE.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_ACTIVEMESSAGINGCHANNELSTATE.fields_by_name['messages'].message_type = _CHANNELMESSAGE
_ACTIVEMESSAGINGCHANNELSTATE.fields_by_name['reply_token'].message_type = _MESSAGEREPLYTOKEN
_ACTIVEMESSAGINGCHANNELSTATE.fields_by_name['sessions'].message_type = _COMPLETEMESSAGINGSESSION
_ACTIVEMESSAGINGCHANNELSTATE.fields_by_name['allowed_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['messages'].message_type = _CHANNELMESSAGE
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['reply_token'].message_type = _MESSAGEREPLYTOKEN
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['sessions'].message_type = _COMPLETEMESSAGINGSESSION
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['allowed_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MESSAGINGCHANNELSTATE.fields_by_name['blocked'].message_type = _BLOCKEDMESSAGINGCHANNELSTATE
_MESSAGINGCHANNELSTATE.fields_by_name['active'].message_type = _ACTIVEMESSAGINGCHANNELSTATE
_MESSAGINGCHANNELSTATE.fields_by_name['in_session'].message_type = _INSESSIONMESSAGINGCHANNELSTATE
_MESSAGINGCHANNELSTATE.oneofs_by_name['state'].fields.append(
  _MESSAGINGCHANNELSTATE.fields_by_name['blocked'])
_MESSAGINGCHANNELSTATE.fields_by_name['blocked'].containing_oneof = _MESSAGINGCHANNELSTATE.oneofs_by_name['state']
_MESSAGINGCHANNELSTATE.oneofs_by_name['state'].fields.append(
  _MESSAGINGCHANNELSTATE.fields_by_name['active'])
_MESSAGINGCHANNELSTATE.fields_by_name['active'].containing_oneof = _MESSAGINGCHANNELSTATE.oneofs_by_name['state']
_MESSAGINGCHANNELSTATE.oneofs_by_name['state'].fields.append(
  _MESSAGINGCHANNELSTATE.fields_by_name['in_session'])
_MESSAGINGCHANNELSTATE.fields_by_name['in_session'].containing_oneof = _MESSAGINGCHANNELSTATE.oneofs_by_name['state']
_MESSAGINGSTATE.fields_by_name['channels'].message_type = _MESSAGINGCHANNELSTATE
DESCRIPTOR.message_types_by_name['ReceivedMessage'] = _RECEIVEDMESSAGE
DESCRIPTOR.message_types_by_name['SentMessage'] = _SENTMESSAGE
DESCRIPTOR.message_types_by_name['MessageReactionState'] = _MESSAGEREACTIONSTATE
DESCRIPTOR.message_types_by_name['MessageReplyToken'] = _MESSAGEREPLYTOKEN
DESCRIPTOR.message_types_by_name['ChannelMessage'] = _CHANNELMESSAGE
DESCRIPTOR.message_types_by_name['CompleteMessagingSession'] = _COMPLETEMESSAGINGSESSION
DESCRIPTOR.message_types_by_name['BlockedMessagingChannelState'] = _BLOCKEDMESSAGINGCHANNELSTATE
DESCRIPTOR.message_types_by_name['ActiveMessagingChannelState'] = _ACTIVEMESSAGINGCHANNELSTATE
DESCRIPTOR.message_types_by_name['InSessionMessagingChannelState'] = _INSESSIONMESSAGINGCHANNELSTATE
DESCRIPTOR.message_types_by_name['MessagingChannelState'] = _MESSAGINGCHANNELSTATE
DESCRIPTOR.message_types_by_name['MessagingState'] = _MESSAGINGSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReceivedMessage = _reflection.GeneratedProtocolMessageType('ReceivedMessage', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVEDMESSAGE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ReceivedMessage)
  })
_sym_db.RegisterMessage(ReceivedMessage)

SentMessage = _reflection.GeneratedProtocolMessageType('SentMessage', (_message.Message,), {
  'DESCRIPTOR' : _SENTMESSAGE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SentMessage)
  })
_sym_db.RegisterMessage(SentMessage)

MessageReactionState = _reflection.GeneratedProtocolMessageType('MessageReactionState', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEREACTIONSTATE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessageReactionState)
  })
_sym_db.RegisterMessage(MessageReactionState)

MessageReplyToken = _reflection.GeneratedProtocolMessageType('MessageReplyToken', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEREPLYTOKEN,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessageReplyToken)
  })
_sym_db.RegisterMessage(MessageReplyToken)

ChannelMessage = _reflection.GeneratedProtocolMessageType('ChannelMessage', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELMESSAGE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ChannelMessage)
  })
_sym_db.RegisterMessage(ChannelMessage)

CompleteMessagingSession = _reflection.GeneratedProtocolMessageType('CompleteMessagingSession', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETEMESSAGINGSESSION,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CompleteMessagingSession)
  })
_sym_db.RegisterMessage(CompleteMessagingSession)

BlockedMessagingChannelState = _reflection.GeneratedProtocolMessageType('BlockedMessagingChannelState', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKEDMESSAGINGCHANNELSTATE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.BlockedMessagingChannelState)
  })
_sym_db.RegisterMessage(BlockedMessagingChannelState)

ActiveMessagingChannelState = _reflection.GeneratedProtocolMessageType('ActiveMessagingChannelState', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVEMESSAGINGCHANNELSTATE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ActiveMessagingChannelState)
  })
_sym_db.RegisterMessage(ActiveMessagingChannelState)

InSessionMessagingChannelState = _reflection.GeneratedProtocolMessageType('InSessionMessagingChannelState', (_message.Message,), {
  'DESCRIPTOR' : _INSESSIONMESSAGINGCHANNELSTATE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.InSessionMessagingChannelState)
  })
_sym_db.RegisterMessage(InSessionMessagingChannelState)

MessagingChannelState = _reflection.GeneratedProtocolMessageType('MessagingChannelState', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGINGCHANNELSTATE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessagingChannelState)
  })
_sym_db.RegisterMessage(MessagingChannelState)

MessagingState = _reflection.GeneratedProtocolMessageType('MessagingState', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGINGSTATE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessagingState)
  })
_sym_db.RegisterMessage(MessagingState)


# @@protoc_insertion_point(module_scope)
